@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: common.c,v 1.6 2005/04/19 21:44:50 evertonm Exp $ */
+/* $Id: common.c,v 1.8 2005/05/30 22:11:50 evertonm Exp $ */
 
 #include <stdio.h>
 #include <assert.h>
@@ -28,13 +28,13 @@ Boston, MA 02111-1307, USA.
 
 
 const char * const NEPIM_LABEL_PARTIAL      = "part";
-const char * const NEPIM_LABEL_TOTAL        = "sum";
-const char * const NEPIM_LABEL_TOTAL_BROKEN = "sum(broken)";
+const char * const NEPIM_LABEL_TOTAL        = "avg";
+const char * const NEPIM_LABEL_TOTAL_BROKEN = "avg(broken)";
 
 
 const char *nepim_version()
 {
-  return "0.6";
+  return "0.7";
 }
 
 void nepim_dump_stat(FILE *out, const char *label, int sd, 
