@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: common.h,v 1.1.1.1 2005/04/09 22:51:38 evertonm Exp $ */
+/* $Id: common.h,v 1.2 2005/04/19 03:40:33 evertonm Exp $ */
 
 #ifndef NEPIM_COMMON_H
 #define NEPIM_COMMON_H
@@ -28,12 +28,19 @@ Boston, MA 02111-1307, USA.
 
 #define NEPIM_MIN(a, b) (((a) < (b)) ? (a) : (b))
 
+
+extern const char * const NEPIM_LABEL_PARTIAL;
+extern const char * const NEPIM_LABEL_TOTAL;
+
+
 const char *nepim_version();
 
 void nepim_dump_stat(FILE *out, const char *label, int sd, 
 		     long long bytes_recv, long long bytes_sent, 
-		     float interval, long sec_start, long sec_duration);
+		     float interval, long sec_start,
+		     long sec_duration, int reads, int writes);
 
 void report_broken_pipe_stat(FILE *out, const nepim_pipe_t *pipe);
 
+
 #endif /* NEPIM_COMMON_H */
