@@ -31,8 +31,10 @@ nepim_global_t nepim_global = {
   -1,     /* bit_rate */
   2,      /* stat_interval */
   10,     /* test_duration */
-  32768,  /* write_size */
-  32768,  /* read_size */
+  32768,  /* tcp_write_size */
+  32768,  /* tcp_read_size */
+  4096,   /* udp_write_size */
+  4096,   /* udp_read_size */
   1234,   /* port */
   0,      /* no_inet6 */
   250000, /* write_delay (usec, bit_rate > 0) */
