@@ -21,7 +21,7 @@ Boston, MA 02111-1307, USA.
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.3 2005/04/12 17:44:44 evertonm Exp $
+  $Id: main.c,v 1.5 2005/04/15 20:57:11 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -60,8 +60,10 @@ static void usage(FILE *out, const char *prog_name)
 	  "-v         show program version\n"
 	  "-p port    server port number (defaults to %d)\n"
 	  "-b address bind to specific local address (defaults to any)\n"
-	  "-w size    segment write size (defaults to %d bytes)\n"
-	  "-z size    segment read size (defaults to %d bytes)\n"
+	  "-w size    TCP write size (defaults to %d bytes)\n"
+	  "-z size    TCP read size (defaults to %d bytes)\n"
+	  "-W size    UDP write size (defaults to %d bytes)\n"
+	  "-Z size    UDP read size (defaults to %d bytes)\n"
 	  "-6         disable IPv6\n"
 	  "\n"
 	  "client-only options:\n"
@@ -75,8 +77,10 @@ static void usage(FILE *out, const char *prog_name)
 	  ,
 	  nepim_global.prog_name, 
 	  nepim_global.port,
-	  nepim_global.write_size,
-	  nepim_global.read_size,
+	  nepim_global.tcp_write_size,
+	  nepim_global.tcp_read_size,
+	  nepim_global.udp_write_size,
+	  nepim_global.udp_read_size,
 	  nepim_global.pipes,
 	  bit_rate,
 	  nepim_global.stat_interval,
@@ -219,22 +223,44 @@ int main(int argc, const char *argv[])
     if (!strcmp(arg, "-w")) {
       ++i;
       if (i >= argc) {
-	fprintf(stderr, "%s: missing write size\n",
+	fprintf(stderr, "%s: missing TCP write size\n",
 		nepim_global.prog_name);
 	exit(1);
       }
-      nepim_global.write_size = atoi(argv[i]);
+      nepim_global.tcp_write_size = atoi(argv[i]);
       continue;
     }
 
     if (!strcmp(arg, "-z")) {
       ++i;
       if (i >= argc) {
-	fprintf(stderr, "%s: missing read size\n",
+	fprintf(stderr, "%s: missing TCP read size\n",
 		nepim_global.prog_name);
 	exit(1);
       }
-      nepim_global.read_size = atoi(argv[i]);
+      nepim_global.tcp_read_size = atoi(argv[i]);
+      continue;
+    }
+
+    if (!strcmp(arg, "-W")) {
+      ++i;
+      if (i >= argc) {
+	fprintf(stderr, "%s: missing UDP write size\n",
+		nepim_global.prog_name);
+	exit(1);
+      }
+      nepim_global.udp_write_size = atoi(argv[i]);
+      continue;
+    }
+
+    if (!strcmp(arg, "-Z")) {
+      ++i;
+      if (i >= argc) {
+	fprintf(stderr, "%s: missing UDP read size\n",
+		nepim_global.prog_name);
+	exit(1);
+      }
+      nepim_global.udp_read_size = atoi(argv[i]);
       continue;
     }
 
@@ -246,19 +272,32 @@ int main(int argc, const char *argv[])
 
   show_version_brief();
 
-  fprintf(stderr, 
-	  "running as %s - read_size=%d write_size=%d\n",
-	  nepim_global.client_mode ? "CLIENT" : "SERVER",
-	  nepim_global.read_size,
-	  nepim_global.write_size);
-
   init_event_loop();
 
   if (nepim_global.client_mode) {
+
+    if (nepim_global.udp_mode)
+      fprintf(stderr, 
+	      "client: udp_read=%d udp_write=%d\n",
+	      nepim_global.udp_read_size,
+	      nepim_global.udp_write_size);
+    else
+      fprintf(stderr, 
+	      "client: tcp_read=%d tcp_write=%d\n",
+	      nepim_global.tcp_read_size,
+	      nepim_global.tcp_write_size);
+
     nepim_client_run();
     exit(0);
   }
 
+  fprintf(stderr, 
+	  "server: tcp_read=%d tcp_write=%d udp_read=%d udp_write=%d\n",
+	  nepim_global.tcp_read_size,
+	  nepim_global.tcp_write_size,
+	  nepim_global.udp_read_size,
+	  nepim_global.udp_write_size);
+
   nepim_server_run();
   exit(0);
 }
